@@ -275,7 +275,7 @@ class Constituent():
                 else:
                     return self.warn("ignored value for option","DT.dOpt",key)
         elif self.isA("NO"):
-            allowedKeys = ["mprecision","raw","nat","ord"]
+            allowedKeys = ["mprecision","raw","nat","ord","rom"]
             if "dOpt" not in self.props:self.props["dOpt"]={}
             for key,val in dOptions.items():
                 if key in allowedKeys:
@@ -363,7 +363,8 @@ class Constituent():
             "they+will":"they'll", "they+are":"they're", "they+had":"they'd", "they+would":"they'd", "they+have":"they've",
             "it+is":"it's", "it+will":"it'll", "it+had":"it'd", "it+would":"it'd",
             "there+will":"there'll", "there+is":"there's", "there+has":"there's", "there+have":"there've",
-            "that+is":"that's", "that+had":"that'd", "that+would":"that'd", "that+will":"that'll"
+            "that+is":"that's", "that+had":"that'd", "that+would":"that'd", "that+will":"that'll",
+            "what+is": "what's"
         } 
         # search for terminal "a" and check if it should be "an" depending on the next word
         last=len(cList)-1
@@ -526,10 +527,10 @@ class Constituent():
                             c.insertReal(pros, Q(c.neg2, "fr"))
                         else:
                             neg2 = c.neg2
-                if c.isReflexive() and c.getProp("t") != "pp":
-                    if prog is not None: c = prog
-                    c.insertReal(pros,
-                                 Pro("moi", "fr").c("refl").pe(c.getProp("pe")).n(c.getProp("n")).g(c.getProp("g")))
+                    if c.isReflexive() and c.getProp("t") != "pp":
+                        if prog is not None: c = prog
+                        c.insertReal(pros,
+                                     Pro("moi", "fr").c("refl").pe(c.getProp("pe")).n(c.getProp("n")).g(c.getProp("g")))
                 i += 1
             elif c.isA("Pro") and verbPos is not None:
                 if c.getProp("pos") is None or (c.parentConst is not None and c.parentConst.getProp("pos") is None):
@@ -707,6 +708,10 @@ class Constituent():
         if "cap" in self.props and self.props["cap"]!=False:
             cList[0].realization=cList[0].realization.capitalize()
  
+        if "tag" in self.props:
+            for attName,attVal in self.props["tag"]:
+                wrapWith(startTag(attName,attVal),"</"+attName+">")
+
         if "a" in self.props:
             for a in self.props["a"]:
                 wrapWith("",getBeforeAfterString(a)["b"])
@@ -721,10 +726,6 @@ class Constituent():
                 ba=getBeforeAfterString(en)
                 wrapWith(ba["b"],ba["a"])
         
-        if "tag" in self.props:
-            for attName,attVal in self.props["tag"]:
-                wrapWith(startTag(attName,attVal),"</"+attName+">")
-
         return cList
     
     def detokenize(self,terminals):
@@ -798,9 +799,9 @@ class Constituent():
                                 getattr(self,opt)(*o)
                             else:
                                 getattr(self,opt)(o)
-                    elif opt not in ["pat","h"]: # do not copy the pat or h properties of a verb
-                        getattr(self,opt)(val)
-                else:
+                    else:
+                        getattr(self, opt)(val)
+                elif opt not in ["pat","h"]: # do not copy the pat or h properties of a verb
                     print("Constituent.fromJSON: illegal prop:"+opt,file=sys.stderr)
         return self                    
     
