@@ -123,12 +123,12 @@ class Dependent(Constituent):
             self.peng={"pengNO":Constituent.pengNO}
             headTerm.peng = self.peng
         for i in range(0,len(self.dependents)): # should use "for d in dependents:"
-            d = self.dependents[i]              # but this "kills" the PyCharm debugger
-            depTerm=d.terminal
-            deprel=d.constType
+            dep = self.dependents[i]              # but this "kills" the PyCharm debugger
+            depTerm=dep.terminal
+            deprel=dep.constType
             if deprel=="subj":
                 if headTerm.isA("V"):
-                    headTerm.peng=d.peng
+                    headTerm.peng=dep.peng
             elif deprel=="det":
                 if depTerm.isA("D"):
                     if hasattr(self,"peng"):
@@ -140,54 +140,61 @@ class Dependent(Constituent):
                             depTerm.peng=self.peng
                 elif depTerm.isA("NO"):
                     depTerm.peng=headTerm.peng
+                elif depTerm.isA("P") and depTerm.lemma == "de":  # HACK: deal with specific case : det(P("de"),mod(D(...)))
+                    if len(dep.dependents)==1 and dep.dependents[0].isA("mod") and dep.dependents[0].isA("D"):
+                        dep.dependents[0].terminal.peng = self.peng
             elif deprel=="mod" or deprel=="comp":
                 if depTerm.isA("A") or (depTerm.isA("V") and depTerm.getProp("t")=="pp"):
-                    depTerm.peng=self.peng
+                    if hasattr(self,"peng"):
+                        depTerm.peng=self.peng
                     # check for an attribute of a copula with an adjective or past participle
                     if self.isFr() and headTerm.lemma in ["être", "paraître", "sembler", "devenir", "rester"]:
                         iSubj=self.findIndex(lambda d0:d0.isA("subj") and d0.terminal.isOneOf(["N","Pro"]))
                         if iSubj>=0:
                             depTerm.peng=self.dependents[iSubj].peng
-                        iAttr=self.findIndex(lambda d0:d0.isA("comp") and
-                                                       (d0.terminal.isA("A") or (d0.terminal.isA("V") and d0.terminal.getProp("t")=="pp")))
-                        if iAttr>=0:
-                            self.dependents[iAttr].peng=depTerm.peng
+                #         iAttr=self.findIndex(lambda d0:d0.isA("comp") and
+                #                                        (d0.terminal.isA("A") or (d0.terminal.isA("V") and d0.terminal.getProp("t")=="pp")))
+                #         if iAttr>=0:
+                #             self.dependents[iAttr].peng=depTerm.peng
                 elif depTerm.isA("V"):
                     # set agreement between the subject of a subordinate or the object of a relative subordinate
-                    iRel=d.findIndex(lambda d0:d0.isOneOf(["subj","comp","mod"]) and
-                                                  d0.terminal.isA("Pro") and
-                                                  d0.terminal.lemma in ["qui","que","who","that"])
+                    iRel=dep.findIndex(lambda depI: depI.isOneOf(["subj", "comp", "mod"]) and
+                                                    depI.terminal.isA("Pro") and
+                                                    depI.terminal.lemma in ["qui", "que", "who", "that"])
                     if iRel>=0:
-                        rel = d.dependents[iRel].constType
+                        rel = dep.dependents[iRel].constType
                         if rel=="subj": # verb agrees with this subject
                             depTerm.peng=self.peng
-                        elif self.isFr():
+                        elif self.isFr(): # rel is comp or mod
+                            # in French past participle can agree with a cod appearing before... keep that info in case
                             depTerm.cod=headTerm
                     # check for past participle in French that should agree with the head
                     if self.isFr() and depTerm.getProp("t")=="pp":
                         depTerm.peng=self.peng
                 elif depTerm.isA("Pro") and depTerm.lemma in ["qui","que","who","that"]:
                     # a relative linked to depTerm in which the new peng should be propagated
-                    depTerm.peng = self.peng
-                    for d0 in d.dependents:
-                        self.setPengRecursive(d0,d0.peng["pengNO"],self.peng)
+                    if hasattr(self,"peng"):
+                        depTerm.peng=self.peng
+                    for depI in dep.dependents:
+                        self.setPengRecursive(depI,depI.peng["pengNO"],self.peng)
             elif deprel=="root":
                 # self.error("An internal root was found")
                 pass
             elif deprel=="coord":
-                if len(d.dependents)>0:
-                    firstDep=d.dependents[0]
+                if len(dep.dependents)>0:
+                    firstDep=dep.dependents[0]
                     if firstDep.isA("subj"):
-                        headTerm.peng=d.peng
+                        headTerm.peng=dep.peng
                     elif firstDep.isA("det"):
-                        d.peng=headTerm.peng
+                        dep.peng=headTerm.peng
                     elif firstDep.isOneOf(["mod","comp"]) and firstDep.terminal.isOneOf(["V","A"]):
                         # consider this as a coordination of verb sharing a subject (the current root)
                         #            or as a coordination of adjectives
                         if hasattr(headTerm,"peng"):
-                            for d0 in d.dependents:
-                                d0.peng=headTerm.peng
-                                d0.terminal.peng=headTerm.peng
+                            dep.peng = headTerm.peng
+                            for depI in dep.dependents:
+                                depI.peng=headTerm.peng
+                                depI.terminal.peng=headTerm.peng
             else:
                 self.error("Strange dependent:"+deprel)
         return
@@ -198,7 +205,7 @@ class Dependent(Constituent):
 
     def findGenderNumberPerson(self,andCombination):
         g=None
-        n="s"
+        n=None
         pe=3
         nb=0
         for i in range(0,len(self.dependents)):
@@ -211,8 +218,7 @@ class Dependent(Constituent):
                 if e.getProp("n")=="p":n="p"
                 propPe=e.getProp("pe")
                 if propPe is not None and propPe<pe:pe=propPe
-        if nb==0: g="m"
-        elif nb>1 and n=="s" and andCombination:n="p"
+        if nb>1 and andCombination:n="p"
         return {"g":g,"n":n,"pe":pe}
 
     # Dependency structure modification but that must be called in the context of the parentConst
@@ -549,22 +555,31 @@ class Dependent(Constituent):
                 if advIdx>=0 and self.dependents[advIdx].terminal.lemma in ["hardly","scarcely","never","seldom"]:
                     neg=True
                 if subjIdx >=0 :
-                    subj=self.dependents[subjIdx].terminal
-                    if subj.isA("Pro"):
-                        if subj.getProp("pe")==1 and aux=="be" and t=="p" and not neg:
+                    subject=self.dependents[subjIdx].terminal
+                    if subject.isA("Pro"):
+                        if subject.getProp("pe")==1 and aux=="be" and t=="p" and not neg:
                             pe=2 # I am => aren't I
-                        elif subj.lemma in ["this","that","nothing"]:
+                        elif subject.lemma in ["this","that","nothing"]:
                             pro=Pro("I").g("n") # it
-                        elif subj.lemma in ["somebody","anybody","nobody","everybody",
+                        elif subject.lemma in ["somebody","anybody","nobody","everybody",
                                             "someone","anyone","everyone"] :
                             pro=Pro("I").n("p") # they
-                            if subj.lemma=="nobody":neg=True
+                            if subject.lemma=="nobody":neg=True
                         else:
-                            pro=subj.clone()
-                        pro=comp(pro)
+                            pro=subject.clone()
+                        pro=subj(pro).pos("post")
+                    elif subject.isA("N"):
+                        pro = self.dependents[subjIdx].clone().pro().pos("post")
                     else:
                         # must wrap into comp("",...) to force pronominalization of children
-                        pro=comp("",self.dependents[subjIdx].clone().pro())
+                        pro=subj(Pro("it").c("nom")).pos("post")
+                else:  #  no subject, but check if the verb is imperative
+                    if t == "ip":
+                        if aux == "do": aux = "will" # change aux when the aux is default
+                        pro = Pro("I").pe(2).n(n).g(g)
+                    else:
+                        pro = Pro("it").c("nom")
+                    pro = subj(pro).pos("post")
                 iDeps=len(self.dependents)-1
                 while iDeps>=0 and self.dependents[iDeps].depPosition()!="post":
                     iDeps-=1
@@ -624,30 +639,40 @@ class Dependent(Constituent):
             self.setProp("pe",pe if pe is not None else 3)
             return self.doFormat(res) # process format for the CP
         # check that all dependents use the same deprel
+        # except if a dependent is another coord
         deprel=self.dependents[0].constType
         noConnect = self.terminal.lemma == ""
         for j in range(0,last): #insert comma after each element
             dj=self.dependents[j]
-            if not dj.isA(deprel):
-                self.warn("inconsistent dependents within a coord",deprel,dj.constType)
             if noConnect or j<last-1:
                 if "a" not in dj.props or "," in dj.props["a"]:
                     dj.props["a"]=[","]
-            res.extend(dj.real())
+            if dj.isA("coord"):
+                res.extend(dj.coordReal())
+            elif not dj.isA(deprel) and deprel != "coord":
+                self.warn("inconsistent dependents within a coord",deprel,dj.constType)
+            else:
+                res.extend(dj.real())
         # insert realisation of the terminal before last...
         res.extend(self.terminal.real())
-        if not self.dependents[last].isA(deprel):
+        lastD = self.dependents[last]
+        if lastD.isA("coord"):
+            res.extend(lastD.coordReal())
+            return self.doFormat(res)
+        elif not lastD.isA(deprel) and deprel != "coord":
             self.warn("inconsistent dependents within a coord",deprel,self.dependents[last].constType)
         # insert last element
         res.extend(self.dependents[last].real())
         # compute the combined gender and number of the coordination once children have been realized
+        # CAUTION: gender and person might not be correct in the case of embedded coord
         selfCoord=self.terminal
         if selfCoord.isA("C"):
             andC="et" if self.isFr() else "and"
             gn=self.findGenderNumberPerson(selfCoord.lemma==andC)
             if gn["g"] is not None:
                 self.setProp("g",gn["g"])
-            self.setProp("n",gn["n"])
+            if gn["n"] is not None:
+                self.setProp("n",gn["n"])
             self.setProp("pe",gn["pe"])
             # for an inserted pronoun, we must override its existing properties...
             if  hasattr(selfCoord,"pronoun"):
