@@ -1,5 +1,5 @@
 from .Constituent import Constituent,quoteOOV, deprels
-from .Number import enToutesLettres, ordinal
+from .Number import enToutesLettres, ordinal, roman
 from .Lexicon import getLexicon,currentLanguage,getLemma,getRules
 
 import datetime, re
@@ -35,7 +35,7 @@ class Terminal(Constituent):
     # TODO: add lang as last parameter
     def setLemma(self,lemma,terminalType=None):
         if terminalType is None: # when it is not called from a Constructor, keep the current terminalType
-            terminalType=type(self).__name__
+            terminalType=self.constType
         if isinstance(lemma, str):
             lemma=lemma.replace("œ","oe").replace("æ","ae")
         self.lemma=lemma
@@ -354,7 +354,8 @@ class Terminal(Constituent):
         # check for "refl" typ (only called for V): Terminal.conjugate_fr
         pc=self.parentConst
         while pc is not None:
-            if pc.isOneOf(["VP","SP","S",*deprels]):
+            # look for the first enclosing S, SP or Dependent with a terminal V
+            if pc.isOneOf(["VP","SP","S"]) or (pc.isOneOf(deprels) and pc.terminal.isA("V")):
                 if "typ" in pc.props:
                     typs=pc.props["typ"]
                     if "refl" in typs and typs["refl"]==True:
@@ -364,6 +365,8 @@ class Terminal(Constituent):
                                 self.warn("ignored reflexive",pat)
                             return False
                         return True
+                if not pc.isA("VP"):  # unless it is VP stop at the first sentence
+                    return False
             pc=pc.parentConst
         return False
 
@@ -398,10 +401,12 @@ class Terminal(Constituent):
             aux.taux["t"]=tempsAux
             aux.realization=aux.realize()
             # change this verb to pp
-            self.setProp("g",g)
-            self.setProp("n",n)
-            self.setProp("t","pp")
-            self.realization=self.realize()
+            pp = V(self.lemma,"fr")
+            pp.setProp("g",g)
+            pp.setProp("n",n)
+            pp.setProp("t","pp")
+            pp.realization=pp.realize()   # realize the pp using jsRealB without other options
+            self.realization=pp.realization  # set verb realization to the pp realization
             if hasattr(self,"neg2"):
                 aux.neg2=self.neg2 # save this flag to put on the auxiliary, 
                 del self.neg2      # delete it on this verb
@@ -563,9 +568,15 @@ class Terminal(Constituent):
     def numberToOrdinal(self):
         if not isinstance(self.value,int) or self.value<0:
             self.warn("bad ordinal",self.value)
-            return str(self.value)
+            return f"[[{self.value}]]"
         return ordinal(self.value,self.lang,self.peng["g"])
-    
+
+    def numberToRoman(self):
+        if not isinstance(self.value,int) or self.value<0 or self.value>=4000:
+            self.warn("bad roman",self.value)
+            return f"[[{self.value}]]"
+        return roman(self.value)
+
     ### Date
     def dateFormat(self,dateObj,dOpts):
         fmtRE=re.compile(r"(.*?)\[(.+?)]|(.+$)")
@@ -650,6 +661,8 @@ class Terminal(Constituent):
                 elif "ord" in opts and opts["ord"]==True:
                     self.setProp("n","s")  # the number of an ordinal is always singular
                     self.realization=self.numberToOrdinal()
+                elif "rom" in opts and opts["rom"]==True:
+                    self.realization=self.numberToRoman()
                 elif "raw" in opts and opts["raw"]==False:
                     self.realization=self.numberFormatter(opts["mprecision"])
                 else: # opts["raw"]==True
